import setuptools
from pathlib import Path


setuptools.setup(
    name="poepdf",
    version=1.0,
    long_description=Path("README.md").read_text(),
    packages=setuptools.find_packages(
        exclude=["tests_prescindible", "data_prescindible"])
)

# Instalar: py -m pip install setuptools wheel twine
#
# Para generar distribution packages (uno 'source', otro 'build'), en la terminal:
#  python setup.py sdist bdist_wheel. Esto crea en el directorio del proyecto varias carpetas:
# build, dist (con las dos distribuciones comprimidas) y nombreproyecto.egg-info.
# Para subirlas a Pypi (usuario: PoeMetrioNabu/ contraseña: B!5E6ejiN@SBN5a#):
# twine upload dist/*
